# COCOPLOT
COlor COllapsed PLOTting quick-look and context image software is designed to convey spectral profile information from all of the spatial pixels in a 3D datacube as a single image, using color.
